==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/CategoryAxisBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AxisDescriptionMetadata } from "./AxisDescriptionMetadata";
/**
 * @hidden
 */
export let CategoryAxisBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class CategoryAxisBaseDescriptionMetadata extends Base {
        static b(a) {
            if (CategoryAxisBaseDescriptionMetadata.a == null) {
                CategoryAxisBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CategoryAxisBaseDescriptionMetadata.c(CategoryAxisBaseDescriptionMetadata.a);
            }
            if (a.j(CategoryAxisBaseDescriptionMetadata.a)) {
                return;
            }
            a.y(CategoryAxisBaseDescriptionMetadata.a);
        }
        static c(a) {
            AxisDescriptionMetadata.c(a);
            a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,wf:ItemsSource)DataRef::object");
            a.item("ItemsCount", "Number:int");
            a.item("Gap", "Number:double");
            a.item("MaximumGap", "Number:double");
            a.item("MinimumGapSize", "Number:double");
            a.item("Overlap", "Number:double");
            a.item("UseClusteringMode", "Boolean");
            a.item("ItemsCountChangeRef", "EventRef::itemsCountChange");
            CategoryAxisBaseDescriptionMetadata.e(a);
        }
        static d(a) {
            CategoryAxisBaseDescriptionMetadata.b(a);
            a.z("CategoryAxisBase", CategoryAxisBaseDescriptionMetadata.a);
        }
        static e(a) {
            a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource)DataRef:String");
        }
    }
    CategoryAxisBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(CategoryAxisBaseDescriptionMetadata, 'CategoryAxisBaseDescriptionMetadata');
    CategoryAxisBaseDescriptionMetadata.a = null;
    return CategoryAxisBaseDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CategoryAxisBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AxisDescriptionMetadata } from "./AxisDescriptionMetadata";
/**
 * @hidden
 */
export let CategoryAxisBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class CategoryAxisBaseDescriptionMetadata extends Base {
        static b(a) {
            if (CategoryAxisBaseDescriptionMetadata.a == null) {
                CategoryAxisBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CategoryAxisBaseDescriptionMetadata.c(CategoryAxisBaseDescriptionMetadata.a);
            }
            if (a.k(CategoryAxisBaseDescriptionMetadata.a)) {
                return;
            }
            a.aa(CategoryAxisBaseDescriptionMetadata.a);
        }
        static c(a) {
            AxisDescriptionMetadata.c(a);
            a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,wf:ItemsSource)DataRef::object");
            a.item("ItemsCount", "Number:int");
            a.item("Gap", "Number:double");
            a.item("MaximumGap", "Number:double");
            a.item("MinimumGapSize", "Number:double");
            a.item("Overlap", "Number:double");
            a.item("UseClusteringMode", "Boolean");
            a.item("ItemsCountChangeRef", "EventRef::itemsCountChange");
            CategoryAxisBaseDescriptionMetadata.e(a);
        }
        static d(a) {
            CategoryAxisBaseDescriptionMetadata.b(a);
            a.ab("CategoryAxisBase", CategoryAxisBaseDescriptionMetadata.a);
        }
        static e(a) {
            a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource)DataRef:String");
        }
    }
    CategoryAxisBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(CategoryAxisBaseDescriptionMetadata, 'CategoryAxisBaseDescriptionMetadata');
    CategoryAxisBaseDescriptionMetadata.a = null;
    return CategoryAxisBaseDescriptionMetadata;
})();
